@@ -7,7 +7,7 @@
   \author  M. Gastineau
            Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris.
 
-   Copyright, 2008-2021, CNRS
+   Copyright, 2008-2024, CNRS
    email of the author : Mickael.Gastineau@obspm.fr
 
  History :
@@ -114,18 +114,18 @@ This content is common to JPL and INPOP files
 /*-------------------------------------------------------------------------*/
 typedef struct
 {
-    char label[3][84];
-    char constName[400][6];
-    double timeData[3];
-    int numConst;
-    double AU;
-    double EMRAT;
-    int coeffPtr[12][3];
-    int DENUM;
-    int libratPtr[3];
+    char label[3][84];       /*!< unused field */
+    char constName[400][6]; /*!< constant name */
+    double timeData[3];/*!<  begin/end/step  */
+    int numConst;  /*!< number of elements of constName */
+    double AU;     /*!< astronomical unit */
+    double EMRAT;  /*!< earth-moon ratio */
+    int coeffPtr[12][3]; /*!< pointer to the coefficients of the planets, ... */
+    int DENUM;     /*!< ephemeris number */
+    int libratPtr[3]; /*!< pointer to the coefficients of the libration */
 }
 #if defined(__GNUC__) || defined(__PGIC__)
-__attribute__ ((packed))
+__attribute__((packed))
 #endif
     t_HeaderBlockBase;
 
@@ -138,7 +138,7 @@ typedef struct
     int TTmTDBPtr[3];           /*!< coefficients size/offset for TT-TDB (only in INPOP) */
 }
 #if defined(__GNUC__) || defined(__PGIC__)
-__attribute__ ((packed))
+__attribute__((packed))
 #endif
     t_HeaderBlockExtensionInpop;
 
@@ -153,7 +153,7 @@ typedef struct
     int TTmTDBPtr[3];
 }
 #if defined(__GNUC__) || defined(__PGIC__)
-__attribute__ ((packed))
+__attribute__((packed))
 #endif
     t_HeaderBlockExtensionJPL;
 
@@ -173,18 +173,18 @@ __attribute__ ((packed))
 /*-------------------------------------------------------------------------*/
 typedef struct
 {
-    char label[3][84];
-    char constName[3000][6];
-    double timeData[3];
-    int numConst;
-    double AU;
-    double EMRAT;
-    int coeffPtr[12][3];
-    int DENUM;
-    int libratPtr[3];
-    int lunarAngularvelocityPtr[3];
-    int TTmTDBPtr[3];
-    int recordsize;
+    char label[3][84];      /*!< unused field */
+    char constName[3000][6]; /*!< constant name */
+    double timeData[3];/*!<  begin/end/step  */
+    int numConst;  /*!< number of elements of constName */
+    double AU;     /*!< astronomical unit */
+    double EMRAT;  /*!< earth-moon ratio */
+    int coeffPtr[12][3]; /*!< pointer to the coefficients of the planets, ... */
+    int DENUM;     /*!< ephemeris number */
+    int libratPtr[3]; /*!< pointer to the coefficients of the libration */
+    int lunarAngularvelocityPtr[3]; /*!< pointer to the coefficients of the angular velocity of the Moon */
+    int TTmTDBPtr[3];  /*!< pointer to the coefficients of the TT-TDB */
+    int recordsize;    /*!< size of the records */
 } t_HeaderBlock;
 
 /*-------------------------------------------------------------------------*/
@@ -236,7 +236,7 @@ typedef struct
     /* following data for prefetching */
     double *mmap_buffer;        /*!< preallocated buffer with mmap */
     size_t mmap_size;           /*!< size of mmap_buffer in bytes */
-    int mmap_used;              /*!< = 1 if mmap was used instaed of malloc */
+    int mmap_used;              /*!< = 1 if mmap was used instead of malloc */
     int prefetch;               /*!< = 1 => the file is prefetched */
 } t_memarcoeff;
 
@@ -320,8 +320,8 @@ int calceph_inpop_open(FILE * file, const char *fileName, struct calcephbin_inpo
 struct calcephbin_inpop calceph_inpop_fdopen(struct calcephbin_inpop *eph);
 void calceph_inpop_close(struct calcephbin_inpop *eph);
 int calceph_inpop_prefetch(struct calcephbin_inpop *eph);
-void calceph_interpol_PV_an(const t_memarcoeff * p_pbinfile, treal TimeJD0, treal Timediff, stateType * Planet,
-                            int C, int G, int N, int ncomp);
+void calceph_interpol_PV_an(const t_memarcoeff * p_pbinfile, treal TimeJD0, treal Timediff,
+                            stateType * Planet, int C, int G, int N, int ncomp);
 
 void calceph_empty_asteroid(t_ast_calcephbin * p_pasteph);
 int calceph_init_asteroid(t_ast_calcephbin * p_pasteph, FILE * file, int swapbyte, double timeData[3],
