@@ -154,6 +154,8 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
 
     int k;
 
+    buffer_error_t buffer_error;
+
     if (n <= 0)
         return NULL;
 
@@ -161,9 +163,12 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
     res = (t_calcephbin *) malloc(sizeof(t_calcephbin));
     if (res == NULL)
     {
-        fatalerror("Can't allocate memory for t_calcephbin\nSystem error : '%s'\n", strerror(errno));
+        /* GCOVR_EXCL_START */
+        fatalerror("Can't allocate memory for t_calcephbin\nSystem error : '%s'\n",
+                   calceph_strerror_errno(buffer_error));
 
         return NULL;
+        /* GCOVR_EXCL_STOP */
     }
     res->etype = CALCEPH_unknown;
     res->data.spkernel.list = NULL;
@@ -190,7 +195,8 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         file = fopen(fileName, "rb");
         if (file == NULL)
         {
-            fatalerror("Unable to open ephemeris file: '%s'\nSystem error : '%s'\n", fileName, strerror(errno));
+            fatalerror("Unable to open ephemeris file: '%s'\nSystem error : '%s'\n", fileName,
+                       calceph_strerror_errno(buffer_error));
             calceph_close(res);
             return NULL;
         }
@@ -204,11 +210,13 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
             fseek(file, 0L, SEEK_SET);
             if (fread(&H1, 7 * sizeof(char), 1, file) != 1)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't read header block from the ephemeris file '%s'\nSystem error : '%s'\n",
-                           fileName, strerror(errno));
+                           fileName, calceph_strerror_errno(buffer_error));
                 fclose(file);
                 calceph_close(res);
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
         }
 
@@ -226,10 +234,12 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         {                       /* SPK files */
             if (res->etype == CALCEPH_ebinary)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't open SPICE kernel and INPOP/original DE files at the same time.\n");
                 fclose(file);
                 calceph_close(res);
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
             res->etype = CALCEPH_espice;
             if ((spicekernel = calceph_spice_addfile(&res->data.spkernel)) == NULL)
@@ -284,10 +294,12 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         {                       /* text PCK files */
             if (res->etype == CALCEPH_ebinary)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't open SPICE kernel and INPOP/original DE files at the same time.\n");
                 fclose(file);
                 calceph_close(res);
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
             res->etype = CALCEPH_espice;
             if ((spicekernel = calceph_spice_addfile(&res->data.spkernel)) == NULL)
@@ -302,7 +314,7 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
                 calceph_close(res);
                 return NULL;
             }
-            if (calceph_txtpck_merge_incrementalassignment(res->data.spkernel.list, spicekernel)==0 
+            if (calceph_txtpck_merge_incrementalassignment(res->data.spkernel.list, spicekernel) == 0
                 || calceph_spice_tablelinkbody_addfile(&res->data.spkernel, spicekernel) == 0)
             {
                 fclose(file);
@@ -314,10 +326,12 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         {                       /* text frame files */
             if (res->etype == CALCEPH_ebinary)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't open SPICE kernel and INPOP/original DE files at the same time.\n");
                 fclose(file);
                 calceph_close(res);
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
             res->etype = CALCEPH_espice;
             if ((spicekernel = calceph_spice_addfile(&res->data.spkernel)) == NULL)
@@ -337,10 +351,12 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         {                       /* text frame files */
             if (res->etype == CALCEPH_ebinary)
             {
+                /* GCOVR_EXCL_START */
                 fatalerror("Can't open SPICE kernel and INPOP/original DE files at the same time.\n");
                 fclose(file);
                 calceph_close(res);
                 return NULL;
+                /* GCOVR_EXCL_STOP */
             }
             res->etype = CALCEPH_espice;
             if (calceph_txtmk_open(file, fileName, &res->data.spkernel) == 0)
@@ -368,11 +384,13 @@ t_calcephbin *calceph_open_array2(int n, char **fileName_array)
         }
         else
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't read header block from the ephemeris file '%s'\nSystem error : '%s'\n", fileName,
-                       strerror(errno));
+                       calceph_strerror_errno(buffer_error));
             fclose(file);
             calceph_close(res);
             return NULL;
+            /* GCOVR_EXCL_STOP */
         }
     }
 
@@ -404,7 +422,8 @@ t_calcephbin *calceph_fdopen(t_calcephbin * eph)
     res = (t_calcephbin *) malloc(sizeof(t_calcephbin));
     if (res == NULL)
     {
-        fatalerror("Can't allocate memory for t_calcephbin\nSystem error : '%s'\n", strerror(errno));
+        fatalerror("Can't allocate memory for t_calcephbin\nSystem error : '%s'\n",
+                   calceph_strerror_errno(buffer_error));
 
         return NULL;
     }
@@ -424,8 +443,10 @@ t_calcephbin *calceph_fdopen(t_calcephbin * eph)
                break; */
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_fdopen\n");
             res = NULL;
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -449,12 +470,14 @@ void calceph_close(t_calcephbin * eph)
             calceph_inpop_close(&eph->data.binary);
             break;
 
+            /* GCOVR_EXCL_START */
         case CALCEPH_unknown:
             break;
 
         default:
             fatalerror("Unknown ephemeris type in calceph_close\n");
             break;
+            /* GCOVR_EXCL_STOP */
     }
     free(eph);
 }
@@ -507,6 +530,7 @@ int calceph_prefetch(t_calcephbin * eph)
             res = calceph_inpop_prefetch(&eph->data.binary);
             break;
 
+            /* GCOVR_EXCL_START */
         case CALCEPH_unknown:
             res = 0;
             break;
@@ -515,6 +539,7 @@ int calceph_prefetch(t_calcephbin * eph)
             fatalerror("Unknown ephemeris type in calceph_prefetch\n");
             res = 0;
             break;
+            /* GCOVR_EXCL_STOP */
     }
     return res;
 }
@@ -541,8 +566,10 @@ int calceph_isthreadsafe(t_calcephbin * eph)
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_isthreadsafe\n");
             res = 0;
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -568,7 +595,9 @@ double calceph_getEMRAT(t_calcephbin * p_pbinfile)
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_close\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return AU;
@@ -594,7 +623,9 @@ double calceph_getAU(t_calcephbin * p_pbinfile)
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_close\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return AU;
@@ -675,7 +706,9 @@ int calceph_getconstantvd(t_calcephbin * p_pbinfile, const char *name, double *a
                 break;
 
             default:
+                /* GCOVR_EXCL_START */
                 fatalerror("Unknown ephemeris type in calceph_getconstantvd\n");
+                /* GCOVR_EXCL_STOP */
                 break;
         }
     }
@@ -766,7 +799,9 @@ int calceph_getconstantvs(t_calcephbin * p_pbinfile, const char *name, t_calceph
                 break;
 
             default:
+                /* GCOVR_EXCL_START */
                 fatalerror("Unknown ephemeris type in calceph_getconstantvs\n");
+                /* GCOVR_EXCL_STOP */
                 break;
         }
     }
@@ -794,7 +829,9 @@ int calceph_getconstantcount(t_calcephbin * eph)
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_getconstantcount\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -827,7 +864,9 @@ int calceph_getconstantindex(t_calcephbin * eph, int index, char name[CALCEPH_MA
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_getconstantindex\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -947,8 +986,10 @@ int calceph_compute_order(t_calcephbin * pephbin, double JD0, double time, int t
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_compute_unit\n");
             res = 0;
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -993,8 +1034,10 @@ int calceph_orient_order(t_calcephbin * eph, double JD0, double time, int target
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_orient_unit/calceph_orient_order\n");
             res = 0;
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
@@ -1040,8 +1083,10 @@ int calceph_rotangmom_order(t_calcephbin * eph, double JD0, double time, int tar
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("Unknown ephemeris type in calceph_rotangmom_unit/calceph_rotangmom_order\n");
             res = 0;
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return res;
