@@ -127,8 +127,9 @@ static int calceph_spk_allocate_directory(int count_directory, double **director
   @param res (out) descriptor of the ephemeris.
 */
 /*--------------------------------------------------------------------------*/
-int calceph_spk_open(FILE *file, const char *filename, struct SPICEkernel *res)
+int calceph_spk_open(FILE * file, const char *filename, struct SPICEkernel *res)
 {
+    buffer_error_t buffer_error;
     struct SPKHeader header;
 
     struct SPKSegmentList *listseg;
@@ -152,15 +153,19 @@ int calceph_spk_open(FILE *file, const char *filename, struct SPICEkernel *res)
     /* go to the head of the file */
     if (fseeko(file, 0, SEEK_SET) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't jump to the beginning of the ephemeris file '%s'\nSystem "
-                   "error : '%s'\n", filename, strerror(errno));
+                   "error : '%s'\n", filename, calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     if (fread(&header, sizeof(header), 1, file) != 1)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't read the beginning of the ephemeris file '%s'\nSystem "
-                   "error : '%s'\n", filename, strerror(errno));
+                   "error : '%s'\n", filename, calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
 
   /*---------------------------------------------------------*/
@@ -177,8 +182,10 @@ int calceph_spk_open(FILE *file, const char *filename, struct SPICEkernel *res)
   /*---------------------------------------------------------*/
     if (calceph_spk_ftp(header.ftp) == 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("The FTP string is not valid in the file '%s'\n", filename);
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
   /*---------------------------------------------------------*/
     /* read the list of segments */
@@ -436,7 +443,7 @@ int calceph_spk_ftp(const unsigned char ftpbuf[FTP_LEN])
    @param reqconvert (in) binary file format
 */
 /*--------------------------------------------------------------------------*/
-static int calceph_spk_readlistsegment(FILE *file, const char *filename, struct SPKSegmentList **list,
+static int calceph_spk_readlistsegment(FILE * file, const char *filename, struct SPKSegmentList **list,
                                        int fwd, int PARAMETER_UNUSED(bwd), enum SPKBinaryFileFormat reqconvert)
 {
 #if HAVE_PRAGMA_UNUSED
@@ -446,6 +453,8 @@ static int calceph_spk_readlistsegment(FILE *file, const char *filename, struct
 
     int res = 1;
 
+    buffer_error_t buffer_error;
+
     do
     {
         char descriptor[DAF_RECORD_LEN];
@@ -473,21 +482,30 @@ static int calceph_spk_readlistsegment(FILE *file, const char *filename, struct
         /* go to the head of the file */
         if (fseeko(file, DAF_RECORD_LEN * (ofwd - 1), SEEK_SET) != 0)
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't jump to the segment descriptor record at location %d of "
-                       "the ephemeris file '%s'\nSystem error : '%s'\n", fwd, filename, strerror(errno));
+                       "the ephemeris file '%s'\nSystem error : '%s'\n",
+                       fwd, filename, calceph_strerror_errno(buffer_error));
             return 0;
+            /* GCOVR_EXCL_STOP */
         }
         if (fread(descriptor, sizeof(char), DAF_RECORD_LEN, file) != DAF_RECORD_LEN)
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't read the segment descriptor record at location  %d of "
-                       "the ephemeris file '%s'\nSystem error : '%s'\n", fwd, filename, strerror(errno));
+                       "the ephemeris file '%s'\nSystem error : '%s'\n",
+                       fwd, filename, calceph_strerror_errno(buffer_error));
             return 0;
+            /* GCOVR_EXCL_STOP */
         }
         if (fread(segmentid, sizeof(char), DAF_RECORD_LEN, file) != DAF_RECORD_LEN)
         {
+            /* GCOVR_EXCL_START */
             fatalerror("Can't read the segment id record at location  %d of the "
-                       "ephemeris file '%s'\nSystem error : '%s'\n", fwd + 1, filename, strerror(errno));
+                       "ephemeris file '%s'\nSystem error : '%s'\n",
+                       fwd + 1, filename, calceph_strerror_errno(buffer_error));
             return 0;
+            /* GCOVR_EXCL_STOP */
         }
 
         calceph_bff_convert_array_double(ddescriptor, DAF_RECORD_LEN / 8, reqconvert);
@@ -579,21 +597,26 @@ static int calceph_spk_readlistsegment(FILE *file, const char *filename, struct
    @param record (out) array to store the words
 */
 /*--------------------------------------------------------------------------*/
-int calceph_spk_readword(FILE *file, const char *filename, int rec_begin, int rec_end, double *record)
+int calceph_spk_readword(FILE * file, const char *filename, int rec_begin, int rec_end, double *record)
 {
+    buffer_error_t buffer_error;
     size_t n = (size_t) (rec_end - rec_begin + 1);
 
     if (fseeko(file, (rec_begin - 1) * sizeof(double), SEEK_SET) != 0)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't jump to the location %lu of the ephemeris file "
-                   "'%s'\nSystem error : '%s'\n", rec_begin, filename, strerror(errno));
+                   "'%s'\nSystem error : '%s'\n", rec_begin, filename, calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
     if (fread(record, sizeof(double), n, file) != n)
     {
+        /* GCOVR_EXCL_START */
         fatalerror("Can't read %d data at location  %d of the ephemeris file "
-                   "'%s'\nSystem error : '%s'\n", n, rec_begin, filename, strerror(errno));
+                   "'%s'\nSystem error : '%s'\n", n, rec_begin, filename, calceph_strerror_errno(buffer_error));
         return 0;
+        /* GCOVR_EXCL_STOP */
     }
 
     return 1;
@@ -633,8 +656,10 @@ int calceph_spk_fastreadword(struct SPKfile *pspk, const struct SPKSegmentHeader
                 cache->buffer = (double *) realloc(cache->buffer, newlen);
                 if (cache->buffer == NULL)
                 {
+                    /* GCOVR_EXCL_START */
                     fatalerror("Can't allocate memory for %lu bytes.\n", (unsigned long) newlen);
                     return 0;
+                    /* GCOVR_EXCL_STOP */
                 }
                 cache->buffer_size = newlen;
             }
@@ -658,7 +683,7 @@ int calceph_spk_fastreadword(struct SPKfile *pspk, const struct SPKSegmentHeader
 
 #if DEBUG
 /*--------------------------------------------------------------------------*/
-/* ! debug the segment
+/*! debug the segment
    @param seg (inout) segment
 */
 /*--------------------------------------------------------------------------*/
@@ -744,14 +769,14 @@ void calceph_spk_debugsegment(struct SPKSegmentHeader *seg)
 #endif
 
 /*--------------------------------------------------------------------------*/
-/* ! read the data header of this segment
+/*! read the data header of this segment
    @param file (inout) file descriptor.
    @param filename (in) A character string giving the name of an ephemeris data
    file.
    @param seg (inout) segment
 */
 /*--------------------------------------------------------------------------*/
-static int calceph_spk_readsegment_header(FILE *file, const char *filename, struct SPKSegmentHeader *seg)
+static int calceph_spk_readsegment_header(FILE * file, const char *filename, struct SPKSegmentHeader *seg)
 {
     double drecord[12];
 
@@ -1014,7 +1039,7 @@ static int calceph_spk_readsegment_header(FILE *file, const char *filename, stru
 */
 /*--------------------------------------------------------------------------*/
 int calceph_spk_interpol_PV_segment(struct SPKfile *pspk, struct SPKSegmentHeader *seg,
-                                    struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType *Planet)
+                                    struct SPICEcache *cache, treal TimeJD0, treal Timediff, stateType * Planet)
 {
     int res = 0;
 
@@ -1158,7 +1183,9 @@ static int calceph_bff_convert_int(int x, enum SPKBinaryFileFormat reqconvert)
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("CALCEPH does not handle this conversion format.\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
     return r;
@@ -1205,7 +1232,9 @@ void calceph_bff_convert_array_double(double *x, int n, enum SPKBinaryFileFormat
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("CALCEPH does not handle this conversion format.\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
 }
@@ -1248,7 +1277,9 @@ void calceph_bff_reorder_array_int(int *x, int n, enum SPKBinaryFileFormat reqco
             break;
 
         default:
+            /* GCOVR_EXCL_START */
             fatalerror("CALCEPH does not handle this conversion format.\n");
+            /* GCOVR_EXCL_STOP */
             break;
     }
 }
